==> hs-Agda-2.3.0.1_1.tbz: lib/ghc-7.4.1/cabal/Agda-2.3.0.1/register.sh <==
#!/bin/sh
echo 'name: Agda
version: 2.3.0.1
id: Agda-2.3.0.1-57ecba050ef25d7388e26c05892eda30

license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
synopsis: A dependently typed functional programming language and proof assistant
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             Note that if you want to use the command-line program (agda), then
             you should also install the Agda-executable package. The Agda
             package includes an Emacs mode for Agda, but you need to set up the
             Emacs mode yourself (for instance by running @agda-mode setup@; see
             the README).
             .
             Note also that this library does not follow the package versioning
             policy, because the library is only intended to be used by the Emacs
             mode and the Agda-executable package.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Catarina Coquand, Makoto Takeyama, Andreas Abel, Darin Morrison...
exposed: True
exposed-modules: Agda.Main Agda.ImpossibleTest
                 Agda.Interaction.BasicOps Agda.Interaction.GhciTop
                 Agda.Compiler.HaskellTypes Agda.Compiler.Epic.AuxAST
                 Agda.Compiler.Epic.CaseOpts Agda.Compiler.Epic.Compiler
                 Agda.Compiler.Epic.CompileState Agda.Compiler.Epic.Epic
                 Agda.Compiler.Epic.Erasure Agda.Compiler.Epic.ForceConstrs
                 Agda.Compiler.Epic.Forcing Agda.Compiler.Epic.FromAgda
                 Agda.Compiler.Epic.Injection Agda.Compiler.Epic.Interface
                 Agda.Compiler.Epic.NatDetection Agda.Compiler.Epic.Primitive
                 Agda.Compiler.Epic.Smashing Agda.Compiler.Epic.Static
                 Agda.Compiler.JS.Case Agda.Compiler.JS.Compiler
                 Agda.Compiler.JS.Syntax Agda.Compiler.JS.Substitution
                 Agda.Compiler.JS.Parser Agda.Compiler.JS.Pretty
                 Agda.Compiler.MAlonzo.Compiler Agda.Compiler.MAlonzo.Encode
                 Agda.Compiler.MAlonzo.Misc Agda.Compiler.MAlonzo.Pretty
                 Agda.Compiler.MAlonzo.Primitives Agda.Packaging.Config
                 Agda.Packaging.Database Agda.Packaging.Monad Agda.Packaging.Types
                 Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.EmacsCommand Agda.Interaction.Exceptions
                 Agda.Interaction.FindFile Agda.Interaction.Highlighting.Dot
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim Agda.Interaction.Imports
                 Agda.Interaction.MakeCase Agda.Interaction.Monad
                 Agda.Interaction.Options Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Notation Agda.Syntax.Parser.Alex
                 Agda.Syntax.Parser.Comments Agda.Syntax.Parser.Layout
                 Agda.Syntax.Parser.LexActions Agda.Syntax.Parser.Lexer
                 Agda.Syntax.Parser.LookAhead Agda.Syntax.Parser.Monad
                 Agda.Syntax.Parser.Parser Agda.Syntax.Parser.StringLiterals
                 Agda.Syntax.Parser.Tokens Agda.Syntax.Parser Agda.Syntax.Position
                 Agda.Syntax.Scope.Base Agda.Syntax.Scope.Monad Agda.Syntax.Strict
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.SparseMatrix
                 Agda.Termination.Semiring Agda.Termination.TermCheck
                 Agda.Termination.Termination Agda.Tests Agda.TypeChecker
                 Agda.TypeChecking.Abstract Agda.TypeChecking.CompiledClause
                 Agda.TypeChecking.CompiledClause.Compile
                 Agda.TypeChecking.CompiledClause.Match
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.Datatypes Agda.TypeChecking.DisplayForm
                 Agda.TypeChecking.Eliminators Agda.TypeChecking.Empty
                 Agda.TypeChecking.EtaContract Agda.TypeChecking.Errors
                 Agda.TypeChecking.Free Agda.TypeChecking.Forcing
                 Agda.TypeChecking.Implicit Agda.TypeChecking.Injectivity
                 Agda.TypeChecking.Irrelevance Agda.TypeChecking.Level
                 Agda.TypeChecking.LevelConstraints Agda.TypeChecking.MetaVars
                 Agda.TypeChecking.MetaVars.Mention
                 Agda.TypeChecking.MetaVars.Occurs Agda.TypeChecking.Monad.Base
                 Agda.TypeChecking.Monad.Builtin Agda.TypeChecking.Monad.Closure
                 Agda.TypeChecking.Monad.Constraints Agda.TypeChecking.Monad.Context
                 Agda.TypeChecking.Monad.Debug Agda.TypeChecking.Monad.Env
                 Agda.TypeChecking.Monad.Exception Agda.TypeChecking.Monad.Imports
                 Agda.TypeChecking.Monad.MetaVars Agda.TypeChecking.Monad.Mutual
                 Agda.TypeChecking.Monad.Open Agda.TypeChecking.Monad.Options
                 Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.Quote Agda.TypeChecking.Rebind
                 Agda.TypeChecking.RecordPatterns Agda.TypeChecking.Records
                 Agda.TypeChecking.Reduce Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Builtin.Coinduction
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.UniversePolymorphism Agda.TypeChecking.With
                 Agda.Utils.VarSet Agda.Utils.Char Agda.Utils.Either
                 Agda.Utils.FileName Agda.Utils.Fresh Agda.Utils.Function
                 Agda.Utils.Generics Agda.Utils.Graph Agda.Utils.Hash
                 Agda.Utils.Impossible Agda.Utils.IO.Binary Agda.Utils.IO.Locale
                 Agda.Utils.IO.UTF8 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe
                 Agda.Utils.Monad Agda.Utils.Permutation Agda.Utils.Pointer
                 Agda.Utils.Pretty Agda.Utils.QuickCheck Agda.Utils.ReadP
                 Agda.Utils.SemiRing Agda.Utils.Size Agda.Utils.String
                 Agda.Utils.Suffix Agda.Utils.TestHelpers Agda.Utils.Trie
                 Agda.Utils.Tuple Agda.Utils.Unicode Agda.Utils.Warshall
                 Agda.Version Agda.Auto.Auto Agda.Auto.Convert Agda.Auto.Typecheck
                 Agda.Auto.NarrowingSearch Agda.Auto.Syntax Agda.Auto.SearchControl
                 Agda.Auto.CaseSplit
hidden-modules: Paths_Agda
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/Agda-2.3.0.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/Agda-2.3.0.1
              /usr/local/lib
hs-libraries: HSAgda-2.3.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.2-5e1b443b0b725755bf380173d85ffb73
         array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         binary-0.5.1.0-a96881bfe5fb08a59464ca45dfe738e3
         bytestring-0.9.2.1-6ff76798e80a342ff74a1c8bcb3f4124
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
         directory-1.1.0.2-265c831825d90ce2ca097745b0e621c1
         filepath-1.3.0.0-973f5e9fbed93e25cbe66dfeb6b99ad9
         hashable-1.1.2.3-1b1ae533e8109c581b837fc0c1a1efb6
         hashtables-1.0.1.6-5cb965b9069e2cbf3a8c78c2bc942080
         haskeline-0.6.4.7-a4eb21d81dc61cd5d3621f9cccec98c2
         haskell-src-exts-1.13.3-58010bc1defafe60fe139e37a1de1f74
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
         old-time-1.1.0.0-b77788a065c86ada9ba279afa5e04576
         pretty-1.1.1.0-74ee6c6be86f83487da68d408cc3ae22
         process-1.1.0.1-18dadd8ad5fc640f55a7afdc7aace500
         syb-0.3.6.1-25afc4081bcba194a5b590534d6cacab
         utf8-string-0.3.7-4732446c14bf3cfaefb7f05a0d68dc5e
         xhtml-3000.2.1-c15f9c980052392611925ff142433273
         zlib-0.5.3.3-25bc90418de17a311a72450ebca404a8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/Agda-2.3.0.1/html/Agda.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/Agda-2.3.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-Agda-2.3.2_1.tbz: lib/ghc-7.4.2/cabal/Agda-2.3.2/register.sh <==
#!/bin/sh
echo 'name: Agda
version: 2.3.2
id: Agda-2.3.2-7ee7271ca5bd465960f7ea38b2adadd5

license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
synopsis: A dependently typed functional programming language and proof assistant
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             This package includes both a command-line program (agda) and an
             Emacs mode. If you want to use the Emacs mode you can set it up by
             running @agda-mode setup@ (see the README).
             .
             Note that the Agda library does not follow the package versioning
             policy, because it is not intended to be used by third-party
             packages.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Andreas Abel, Makoto Takeyama, Catarina Coquand, with contributions by Stevan Andjelkovic, Marcin Benke, Jean-Philippe Bernardy, James Chapman, Dominique Devriese, Peter Divanski, Fredrik Nordvall Forsberg, Olle Frediksson, Daniel Gustafsson, Alan Jeffrey, Fredrik Lindblad, Guilhem Moulin, Nicolas Pouillard, Andrés Sicard-Ramírez and many more.
exposed: True
exposed-modules: Agda.Main Agda.ImpossibleTest
                 Agda.Interaction.BasicOps Agda.Interaction.GhcTop
                 Agda.Interaction.InteractionTop Agda.Compiler.CallCompiler
                 Agda.Compiler.HaskellTypes Agda.Compiler.Epic.AuxAST
                 Agda.Compiler.Epic.CaseOpts Agda.Compiler.Epic.Compiler
                 Agda.Compiler.Epic.CompileState Agda.Compiler.Epic.Epic
                 Agda.Compiler.Epic.Erasure Agda.Compiler.Epic.ForceConstrs
                 Agda.Compiler.Epic.Forcing Agda.Compiler.Epic.FromAgda
                 Agda.Compiler.Epic.Injection Agda.Compiler.Epic.Interface
                 Agda.Compiler.Epic.NatDetection Agda.Compiler.Epic.Primitive
                 Agda.Compiler.Epic.Smashing Agda.Compiler.Epic.Static
                 Agda.Compiler.JS.Case Agda.Compiler.JS.Compiler
                 Agda.Compiler.JS.Syntax Agda.Compiler.JS.Substitution
                 Agda.Compiler.JS.Parser Agda.Compiler.JS.Pretty
                 Agda.Compiler.MAlonzo.Compiler Agda.Compiler.MAlonzo.Encode
                 Agda.Compiler.MAlonzo.Misc Agda.Compiler.MAlonzo.Pretty
                 Agda.Compiler.MAlonzo.Primitives Agda.Packaging.Config
                 Agda.Packaging.Database Agda.Packaging.Monad Agda.Packaging.Types
                 Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.EmacsCommand Agda.Interaction.Exceptions
                 Agda.Interaction.FindFile Agda.Interaction.Highlighting.Dot
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim
                 Agda.Interaction.Highlighting.LaTeX Agda.Interaction.Imports
                 Agda.Interaction.Response Agda.Interaction.MakeCase
                 Agda.Interaction.Monad Agda.Interaction.Options
                 Agda.Syntax.Abstract.Copatterns Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Notation Agda.Syntax.Parser.Alex
                 Agda.Syntax.Parser.Comments Agda.Syntax.Parser.Layout
                 Agda.Syntax.Parser.LexActions Agda.Syntax.Parser.Lexer
                 Agda.Syntax.Parser.LookAhead Agda.Syntax.Parser.Monad
                 Agda.Syntax.Parser.Parser Agda.Syntax.Parser.StringLiterals
                 Agda.Syntax.Parser.Tokens Agda.Syntax.Parser Agda.Syntax.Position
                 Agda.Syntax.Scope.Base Agda.Syntax.Scope.Monad
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.SparseMatrix
                 Agda.Termination.Semiring Agda.Termination.TermCheck
                 Agda.Termination.Termination Agda.Tests Agda.TypeChecker
                 Agda.TypeChecking.Abstract Agda.TypeChecking.CompiledClause
                 Agda.TypeChecking.CompiledClause.Compile
                 Agda.TypeChecking.CompiledClause.Match
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.Coverage.SplitTree Agda.TypeChecking.Datatypes
                 Agda.TypeChecking.DisplayForm Agda.TypeChecking.DropArgs
                 Agda.TypeChecking.Eliminators Agda.TypeChecking.Empty
                 Agda.TypeChecking.EtaContract Agda.TypeChecking.Errors
                 Agda.TypeChecking.Free Agda.TypeChecking.Forcing
                 Agda.TypeChecking.Implicit Agda.TypeChecking.Injectivity
                 Agda.TypeChecking.InstanceArguments Agda.TypeChecking.Irrelevance
                 Agda.TypeChecking.Level Agda.TypeChecking.LevelConstraints
                 Agda.TypeChecking.MetaVars Agda.TypeChecking.MetaVars.Mention
                 Agda.TypeChecking.MetaVars.Occurs Agda.TypeChecking.Monad.Base
                 Agda.TypeChecking.Monad.Builtin Agda.TypeChecking.Monad.Closure
                 Agda.TypeChecking.Monad.Constraints Agda.TypeChecking.Monad.Context
                 Agda.TypeChecking.Monad.Debug Agda.TypeChecking.Monad.Env
                 Agda.TypeChecking.Monad.Exception Agda.TypeChecking.Monad.Imports
                 Agda.TypeChecking.Monad.MetaVars Agda.TypeChecking.Monad.Mutual
                 Agda.TypeChecking.Monad.Open Agda.TypeChecking.Monad.Options
                 Agda.TypeChecking.Monad.Sharing Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.ProjectionLike Agda.TypeChecking.Quote
                 Agda.TypeChecking.Rebind Agda.TypeChecking.RecordPatterns
                 Agda.TypeChecking.Records Agda.TypeChecking.Reduce
                 Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Builtin.Coinduction
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.ProblemRest
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.UniversePolymorphism Agda.TypeChecking.With
                 Agda.Utils.VarSet Agda.Utils.Char Agda.Utils.Either
                 Agda.Utils.FileName Agda.Utils.Fresh Agda.Utils.Function
                 Agda.Utils.Geniplate Agda.Utils.Graph Agda.Utils.Hash
                 Agda.Utils.HashMap Agda.Utils.Impossible Agda.Utils.IO.Binary
                 Agda.Utils.IO.UTF8 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe
                 Agda.Utils.Monad Agda.Utils.Permutation Agda.Utils.Pointer
                 Agda.Utils.Pointed Agda.Utils.Pretty Agda.Utils.QuickCheck
                 Agda.Utils.ReadP Agda.Utils.SemiRing Agda.Utils.Size
                 Agda.Utils.String Agda.Utils.Suffix Agda.Utils.TestHelpers
                 Agda.Utils.Time Agda.Utils.Trie Agda.Utils.Tuple Agda.Utils.Unicode
                 Agda.Utils.Warshall Agda.Version Agda.Auto.Auto Agda.Auto.Convert
                 Agda.Auto.Typecheck Agda.Auto.NarrowingSearch Agda.Auto.Syntax
                 Agda.Auto.SearchControl Agda.Auto.CaseSplit
hidden-modules: Paths_Agda
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/Agda-2.3.2
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/Agda-2.3.2
              /usr/local/lib
hs-libraries: HSAgda-2.3.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.5.1.1-b0101c9f2f49da67b606fa3478ecc4d1
         array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         binary-0.5.1.0-7d22596bb2c03e233a921965830a1e7b
         bytestring-0.9.2.1-e22c77999d0db34f3ca8de7082a3ffd5
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
         directory-1.1.0.2-0d703b400bafcc2a2ca486a922be0178
         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
         geniplate-0.6.0.3-3f209c67c195ab041c49b00226b590d6
         hashable-1.2.0.5-616c9310810e53cea406a20719f1a423
         hashtables-1.1.0.2-b3848889a6969ede6d446bfe78305411
         haskeline-0.7.0.3-44ca8cfb392cfbcebdb0e296e93f8464
         haskell-src-exts-1.13.5-a60a31d89dddcba5e5a6390743c94aa5
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         old-time-1.1.0.0-3e0f7b48d6c1d1415ad852e23725fdc1
         parallel-3.2.0.3-0c734151f27a50a329a35e705f0ba330
         pretty-1.1.1.0-867dcdeb02592f3d2a707618561c7b86
         process-1.1.0.1-c55e7a2b0eb5149f070b14e14bea1c83
         text-0.11.2.3-366962ac4488fc093d5aed19e281b055
         unordered-containers-0.2.3.0-2418b77932f7b961dfa1314968c1e9ff
         xhtml-3000.2.1-871d522ce456ce18e4de6a55cd790945
         zlib-0.5.4.0-0d818ac207ea095f2439042e85ca4d8f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/Agda-2.3.2/html/Agda.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/Agda-2.3.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
